@@ -17,6 +17,7 @@
 #include <zypp-core/base/Regex.h>
 #include <stdexcept>
 #include <iostream>
+#include <utility>
 
 
 //////////////////////////////////////////////////////////////////////
@@ -52,17 +53,20 @@ namespace zypp
         configure();
       }
 
-      LDAPUrl(const LDAPUrl &url): UrlBase(url)
-      {}
+      LDAPUrl(LDAPUrl &&) = default;
+      LDAPUrl &operator=(const LDAPUrl &) = default;
+      LDAPUrl &operator=(LDAPUrl &&) = default;
+      LDAPUrl(const LDAPUrl &url) : UrlBase(url) {}
+      ~LDAPUrl() override = default;
 
-      virtual UrlBase *
-      clone() const
+      UrlBase *
+      clone() const override
       {
         return new LDAPUrl(*this);
       }
 
-      virtual UrlSchemes
-      getKnownSchemes() const
+      UrlSchemes
+      getKnownSchemes() const override
       {
         UrlSchemes schemes(2);
         schemes[0] = "ldap";
@@ -70,8 +74,8 @@ namespace zypp
         return schemes;
       }
 
-      virtual void
-      configure()
+      void
+      configure() override
       {
         config("sep_pathparams",  "");
 
@@ -90,8 +94,8 @@ namespace zypp
         config("rx_pathparams",   "");
       }
 
-      virtual zypp::url::ParamMap
-      getQueryStringMap(zypp::url::EEncoding eflag) const
+      zypp::url::ParamMap
+      getQueryStringMap(zypp::url::EEncoding eflag) const override
       {
         static const char * const keys[] = {
           "attrs", "scope", "filter", "exts", NULL
@@ -117,8 +121,8 @@ namespace zypp
         return pmap;
       }
 
-      virtual void
-      setQueryStringMap(const zypp::url::ParamMap &pmap)
+      void
+      setQueryStringMap(const zypp::url::ParamMap &pmap) override
       {
         static const char * const keys[] = {
           "attrs", "scope", "filter", "exts", NULL
@@ -165,7 +169,7 @@ namespace zypp
     class UrlByScheme
     {
     private:
-      typedef std::map<std::string,UrlRef> UrlBySchemeMap;
+      using UrlBySchemeMap = std::map<std::string, UrlRef>;
       UrlBySchemeMap urlByScheme;
 
     public:
@@ -305,8 +309,8 @@ namespace zypp
 
 
   // -----------------------------------------------------------------
-  Url::Url(const zypp::url::UrlRef &url)
-    : m_impl( url)
+  Url::Url(zypp::url::UrlRef url)
+    : m_impl(std::move( url))
   {
     if( !m_impl)
     {
@@ -361,7 +365,7 @@ namespace zypp
   Url::registerScheme(const std::string &scheme,
                       UrlRef            urlImpl)
   {
-    return g_urlSchemeRepository().addUrlByScheme(scheme, urlImpl);
+    return g_urlSchemeRepository().addUrlByScheme(scheme, std::move(urlImpl));
   }
 
 
