@@ -33,7 +33,7 @@ namespace zypp::io {
     if ( fd == -1 )
     { ERR << strerror( errno ) << std::endl; return BlockingMode::FailedToSetMode; }
 
-    int flags = ::fcntl( fd, F_GETFL );
+    int flags = zyppng::eintrSafeCall( ::fcntl, fd, F_GETFL );
 
     if ( flags == -1 )
     { ERR << strerror( errno ) << std::endl; return BlockingMode::FailedToSetMode; }
@@ -44,7 +44,7 @@ namespace zypp::io {
     else if ( flags & O_NONBLOCK )
       flags = flags ^ O_NONBLOCK;
 
-    flags = ::fcntl( fd,F_SETFL,flags );
+    flags = zyppng::eintrSafeCall( ::fcntl, fd,F_SETFL,flags );
 
     if ( flags == -1 )
     { ERR << strerror(errno) << std::endl; return BlockingMode::FailedToSetMode; }
@@ -177,9 +177,7 @@ namespace zypp::io {
 
     std::vector<char> data( count + 1 , '\0' );
 
-    ssize_t l = -1;
-    while ((l = pread( fileno( fd ), data.data(), count, offset ) ) == -1 && errno == EINTR)
-      ;
+    ssize_t l = zyppng::eintrSafeCall( pread, fileno( fd ), data.data(), count, offset );
     if (l == -1)
       return {};
 
