@@ -24,6 +24,7 @@
 
 #include <iostream>
 #include <optional>
+#include <utility>
 
 // in the Estonian locale, a-z excludes t, for example. #302525
 // http://en.wikipedia.org/wiki/Estonian_alphabet
@@ -106,7 +107,7 @@ namespace zypp
     /*
     ** Behaviour configuration variables.
     */
-    typedef std::map< std::string, std::string > UrlConfig;
+    using UrlConfig = std::map<std::string, std::string>;
 
 
     // ---------------------------------------------------------------
@@ -181,8 +182,8 @@ namespace zypp
       UrlBaseData()
       {}
 
-      UrlBaseData(const UrlConfig &conf)
-        : config(conf)
+      UrlBaseData(UrlConfig conf)
+        : config(std::move(conf))
       {}
 
       UrlConfig       config;
@@ -581,7 +582,7 @@ namespace zypp
         tmp.pathname = getPathName(zypp::url::E_ENCODED);
         if( !tmp.pathname.empty())
         {
-          if(url.find("/") != std::string::npos)
+          if(url.find('/') != std::string::npos)
           {
             // Url contains authority (that may be empty),
             // we may need a rewrite of the encoded path.
@@ -607,7 +608,7 @@ namespace zypp
           }
         }
         else if( opts.has(ViewOptions::EMPTY_PATH_NAME)
-                 && url.find("/") != std::string::npos)
+                 && url.find('/') != std::string::npos)
         {
           url += "/";
           if( opts.has(ViewOptions::EMPTY_PATH_PARAMS))
@@ -915,7 +916,7 @@ namespace zypp
     UrlBase::setAuthority(const std::string &authority)
     {
       std::string s = authority;
-      std::string::size_type p,q;
+      std::string::size_type p = 0,q = 0;
 
       std::string username, password, host, port;
 
