@@ -1,6 +1,7 @@
 #include "timer.h"
 #include "private/eventdispatcher_glib_p.h"
 #include "private/threaddata_p.h"
+#include <zypp-core/zyppng/base/private/linuxhelpers_p.h>
 
 #include <zypp-core/base/Exception.h>
 #include <zypp-core/base/Logger.h>
@@ -234,11 +235,10 @@ static gboolean  eventLoopIdleFunc ( gpointer user_data )
     if( dPtr->runIdleTasks() ) {
       return G_SOURCE_CONTINUE;
     }
+
+    g_source_unref ( dPtr->_idleSource );
+    dPtr->_idleSource = nullptr;
   }
-
-  g_source_unref ( dPtr->_idleSource );
-  dPtr->_idleSource = nullptr;
-
   return G_SOURCE_REMOVE;
 }
 
@@ -247,7 +247,7 @@ GlibWaitPIDData::GlibWaitPIDData( GPid pid  )
   source = g_child_watch_source_new( pid );
 }
 
-GlibWaitPIDData::GlibWaitPIDData(GlibWaitPIDData &&other)
+GlibWaitPIDData::GlibWaitPIDData(GlibWaitPIDData &&other)  noexcept
   : tag( other.tag )
   , source( other.source )
   , callback( std::move( other.callback ) )
@@ -263,7 +263,7 @@ GlibWaitPIDData::~GlibWaitPIDData()
   }
 }
 
-GlibWaitPIDData &GlibWaitPIDData::operator=(GlibWaitPIDData &&other)
+GlibWaitPIDData &GlibWaitPIDData::operator=(GlibWaitPIDData &&other)  noexcept
 {
   tag = other.tag;
   source = other.source;
@@ -500,7 +500,7 @@ bool EventDispatcher::waitForFdEvent( const int fd, int events , int &revents ,
   zypp::AutoDispose<GTimer *> timer( g_timer_new(), &g_timer_destroy );
   while ( !eventTriggered ) {
     g_timer_start( *timer );
-    const int res = g_poll( &pollFd, 1, timeout );
+    const int res = eintrSafeCall( g_poll, &pollFd, 1, timeout );
     switch ( res ) {
       case 0: //timeout
         timeout = 0;
@@ -515,9 +515,6 @@ bool EventDispatcher::waitForFdEvent( const int fd, int events , int &revents ,
         if ( timeout <= 0 )
           return false;
 
-        if ( errno == EINTR )
-          continue;
-
         ERR << "g_poll error: " << strerror(errno) << std::endl;
         return false;
       }
@@ -578,10 +575,10 @@ void EventDispatcher::invokeOnIdleImpl(EventDispatcher::IdleFunction &&callback)
   d->enableIdleSource();
 }
 
-void EventDispatcher::unrefLaterImpl(std::shared_ptr<void> &&ptr )
+void EventDispatcher::unrefLaterImpl( std::shared_ptr<void> &&ptr )
 {
   Z_D();
-  d->_unrefLater.push_back( std::forward< std::shared_ptr<void> >(ptr) );
+  d->_unrefLater.push_back( std::move(ptr) );
   d->enableIdleSource();
 }
 
