@@ -11,7 +11,7 @@
 */
 #include "private/curlhelper_p.h"
 
-#include <zypp/APIConfig.h>
+#include <zypp-core/Globals.h>
 
 #include <zypp-core/fs/PathInfo.h>
 #include <zypp-core/Pathname.h>
@@ -385,6 +385,7 @@ Url clearQueryString(const Url &url)
   curlUrl.delQueryParam("ssl_capath");
   curlUrl.delQueryParam("ssl_verify");
   curlUrl.delQueryParam("ssl_clientcert");
+  curlUrl.delQueryParam("ssl_clientkey");
   curlUrl.delQueryParam("timeout");
   curlUrl.delQueryParam("auth");
   curlUrl.delQueryParam("username");
