@@ -6,7 +6,7 @@
 |                         /_____||_| |_| |_|                           |
 |                                                                      |
 ----------------------------------------------------------------------*/
-#include <zypp/APIConfig.h>
+#include <zypp-core/Globals.h>
 #include <zypp-curl/ng/network/private/networkrequestdispatcher_p.h>
 #include <zypp-curl/ng/network/private/networkrequesterror_p.h>
 #include <zypp-curl/ng/network/private/request_p.h>
@@ -258,7 +258,7 @@ void NetworkRequestDispatcherPrivate::handleMultiSocketAction(curl_socket_t nati
   }
 }
 
-void NetworkRequestDispatcherPrivate::cancelAll( NetworkRequestError result )
+void NetworkRequestDispatcherPrivate::cancelAll( const NetworkRequestError& result )
 {
   //prevent dequeuePending from filling up the runningDownloads again
   zypp::DtorReset lockReset( _locked );
@@ -383,7 +383,7 @@ bool NetworkRequestDispatcher::supportsProtocol( const Url &url )
   // curl_info does not need any free (is static)
   if (curl_info->protocols)
   {
-    const char * const *proto;
+    const char * const *proto = nullptr;
     std::string        scheme( url.getScheme() );
     bool               found = false;
     for(proto=curl_info->protocols; !found && *proto; ++proto) {
