@@ -41,7 +41,7 @@ namespace zyppng {
     } _protocolMode = ProtocolMode::Default;
 
     NetworkRequestPrivate(Url &&url, zypp::Pathname &&targetFile, NetworkRequest::FileMode fMode, NetworkRequest &p );
-    virtual ~NetworkRequestPrivate();
+    ~NetworkRequestPrivate() override;
 
     bool initialize( std::string &errBuf );
 
@@ -86,6 +86,7 @@ namespace zyppng {
     void setResult ( NetworkRequestError &&err );
     void reset ();
     void resetActivityTimer ();
+
     void onActivityTimeout (Timer &);
 
     std::string errorMessage () const;
@@ -134,6 +135,7 @@ namespace zyppng {
 
     size_t headerfunction ( char *ptr, size_t bytes ) override;
     size_t writefunction  (char *ptr, std::optional<off_t> offset, size_t bytes ) override;
+    void notifyErrorCodeChanged () override;
 
     std::unique_ptr< curl_slist, decltype (&curl_slist_free_all) > _headers;
 
