@@ -38,10 +38,6 @@ namespace zyppng {
   }
 
   class ProvideQueue;
-  class RpcMessageStream;
-  using RpcMessageStreamPtr = std::shared_ptr<RpcMessageStream>;
-
-
   class ProvidePrivate : public BasePrivate
   {
     ZYPP_DECLARE_PUBLIC(Provide);
@@ -89,6 +85,8 @@ namespace zyppng {
 
     zypp::media::CredManagerOptions &credManagerOptions ();
 
+    std::vector<zypp::Url> sanitizeUrls ( const std::vector<zypp::Url> &urls );
+
     ProvideStatusRef log () {
       return _log;
     }
