@@ -17,6 +17,7 @@
 #include <list>
 #include <set>
 #include <string>
+#include <utility>
 
 #include <zypp/base/Iterable.h>
 #include <zypp/base/PtrTypes.h>
@@ -45,7 +46,7 @@ namespace zypp
   /// \class BadKeyException
   /// \brief Exception thrown when the supplied key is not a valid gpg key
   ///////////////////////////////////////////////////////////////////
-  class BadKeyException : public Exception
+  class ZYPP_API BadKeyException : public Exception
   {
     public:
       /** Ctor taking message.
@@ -61,11 +62,11 @@ namespace zypp
       /** Ctor taking message.
        * Use \ref ZYPP_THROW to throw exceptions.
        */
-      BadKeyException( const std::string & msg_r, const Pathname &keyfile = Pathname() )
-      : Exception( msg_r ), _keyfile(keyfile)
+      BadKeyException( const std::string & msg_r, Pathname keyfile = Pathname() )
+      : Exception( msg_r ), _keyfile(std::move(keyfile))
       {}
       /** Dtor. */
-      virtual ~BadKeyException() throw() {};
+      ~BadKeyException() throw() override {};
     private:
       Pathname _keyfile;
   };
@@ -76,7 +77,7 @@ namespace zypp
   /// \brief Class representing a GPG Public Keys subkeys.
   /// \see \ref PublicKeyData.
   ///////////////////////////////////////////////////////////////////
-  class PublicSubkeyData
+  class ZYPP_API PublicSubkeyData
   {
   public:
     /** Default constructed: empty data. */
@@ -133,7 +134,7 @@ namespace zypp
   /// \brief Class representing a signature on a GPG Public Key.
   /// \see \ref PublicKeyData.
   ///////////////////////////////////////////////////////////////////
-  class PublicKeySignatureData
+  class ZYPP_API PublicKeySignatureData
   {
   public:
     /** Default constructed: empty data. */
@@ -203,7 +204,7 @@ namespace zypp
   /// armored version of the key placed in a tempfile. In this
   /// case use \ref PublicKey.
   ///////////////////////////////////////////////////////////////////
-  class PublicKeyData
+  class ZYPP_API PublicKeyData
   {
   public:
     /** Default constructed: empty data. */
@@ -211,6 +212,11 @@ namespace zypp
 
     ~PublicKeyData();
 
+    PublicKeyData(const PublicKeyData &) = default;
+    PublicKeyData(PublicKeyData &&) noexcept = default;
+    PublicKeyData &operator=(const PublicKeyData &) = default;
+    PublicKeyData &operator=(PublicKeyData &&) noexcept = default;
+
     /** Whether this contains valid data (not default constructed). */
     explicit operator bool() const;
 
@@ -279,8 +285,8 @@ namespace zypp
     std::string asString() const;
 
   public:
-    typedef const PublicSubkeyData * SubkeyIterator;
-    typedef const PublicKeySignatureData * KeySignatureIterator;
+    using SubkeyIterator = const PublicSubkeyData *;
+    using KeySignatureIterator = const PublicKeySignatureData *;
 
     /** Whether \ref subkeys is not empty. */
     bool hasSubkeys() const;
@@ -308,7 +314,7 @@ namespace zypp
 
   public:
     /** Random art fingerprint visualization type (\ref base::DrunkenBishop). */
-    typedef base::DrunkenBishop AsciiArt;
+    using AsciiArt = base::DrunkenBishop;
 
     /** Random art fingerprint visualization (\ref base::DrunkenBishop).
      * \code
@@ -335,10 +341,10 @@ namespace zypp
   { return str << obj.asString(); }
 
   /** \relates PublicKeyData Detailed stream output */
-  std::ostream & dumpOn( std::ostream & str, const PublicKeyData & obj );
+  std::ostream & dumpOn( std::ostream & str, const PublicKeyData & obj ) ZYPP_API;
 
   /** \relates PublicKeyData Equal based on  fingerprint anf creation date. */
-  bool operator==( const PublicKeyData & lhs, const PublicKeyData & rhs );
+  bool operator==( const PublicKeyData & lhs, const PublicKeyData & rhs ) ZYPP_API;
 
   /** \relates PublicKeyData NotEqual. */
   inline bool operator!=( const PublicKeyData & lhs, const PublicKeyData & rhs )
@@ -355,7 +361,7 @@ namespace zypp
   /// keys, the \b last keys data are made available via the API. The
   /// additional keys data are made available via \ref hiddenKeys.
   ///////////////////////////////////////////////////////////////////
-  class PublicKey
+  class ZYPP_API PublicKey
   {
   public:
     /** Implementation  */
@@ -392,7 +398,7 @@ namespace zypp
     /** The public keys data (\see \ref PublicKeyData).*/
     const PublicKeyData & keyData() const;
 
-    typedef PublicKeyData::SubkeyIterator SubkeyIterator;
+    using SubkeyIterator = PublicKeyData::SubkeyIterator;
 
     bool isValid() const
     { return ! ( id().empty() || fingerprint().empty() ); }
@@ -427,7 +433,7 @@ namespace zypp
     { return PublicKeyData::isSafeKeyId(id_r); }
 
   public:
-    typedef PublicKeyData::AsciiArt AsciiArt;	///!< \see \ref PublicKeyData
+    using AsciiArt = PublicKeyData::AsciiArt;	///!< \see \ref PublicKeyData
 
     AsciiArt asciiArt() const			///!< \see \ref PublicKeyData
     { return keyData().asciiArt(); }
@@ -470,7 +476,7 @@ namespace zypp
   { return str << obj.asString(); }
 
   /** \relates PublicKey Detailed stream output */
-  std::ostream & dumpOn( std::ostream & str, const PublicKey & obj );
+  std::ostream & dumpOn( std::ostream & str, const PublicKey & obj ) ZYPP_API;
 
  /////////////////////////////////////////////////////////////////
 } // namespace zypp
