@@ -27,6 +27,9 @@
 #include <zypp/repo/ServiceType.h>
 #include <zypp/ServiceInfo.h>
 #include <zypp/RepoStatus.h>
+#include <zypp/RepoManagerFlags.h>
+#include <zypp/RepoManagerOptions.h>
+#include <utility>
 #include <zypp-core/ui/ProgressData>
 
 ///////////////////////////////////////////////////////////////////
@@ -46,65 +49,13 @@ namespace zypp
     * \throws ParseException If the file parsing fails
     * \throws Exception On other errors.
     */
-   std::list<RepoInfo> readRepoFile(const Url & repo_file);
-
-  /**
-   * Repo manager settings.
-   * Settings default to ZYpp global settings.
-   */
-  struct RepoManagerOptions
-  {
-    /** Default ctor following \ref ZConfig global settings.
-     * If an optional \c root_r directory is given, all paths  will
-     * be prefixed accordingly.
-     * \code
-     *    root_r\repoCachePath
-     *          \repoRawCachePath
-     *          \repoSolvCachePath
-     *          \repoPackagesCachePath
-     *          \knownReposPath
-     * \endcode
-     */
-    RepoManagerOptions( const Pathname & root_r = Pathname() );
-
-    /** Test setup adjusting all paths to be located below one \c root_r directory.
-     * \code
-     *    root_r\          - repoCachePath
-     *          \raw       - repoRawCachePath
-     *          \solv      - repoSolvCachePath
-     *          \packages  - repoPackagesCachePath
-     *          \repos.d   - knownReposPath
-     * \endcode
-     */
-    static RepoManagerOptions makeTestSetup( const Pathname & root_r );
-
-    Pathname repoCachePath;
-    Pathname repoRawCachePath;
-    Pathname repoSolvCachePath;
-    Pathname repoPackagesCachePath;
-    Pathname knownReposPath;
-    Pathname knownServicesPath;
-    Pathname pluginsPath;
-    bool probe;
-    /**
-     * Target distro ID to be used when refreshing repo index services.
-     * Repositories not maching this ID will be skipped/removed.
-     *
-     * If empty, \ref Target::targetDistribution() will be used instead.
-     */
-    std::string servicesTargetDistro;
-
-    /** remembers root_r value for later use */
-    Pathname rootDir;
-  };
-
-
+   std::list<RepoInfo> readRepoFile(const Url & repo_file) ZYPP_API;
 
   /**
    * \short creates and provides information about known sources.
    *
    */
-  class RepoManager
+  class ZYPP_API RepoManager
   {
     friend std::ostream & operator<<( std::ostream & str, const RepoManager & obj );
 
@@ -113,44 +64,38 @@ namespace zypp
     struct Impl;
 
     /** ServiceInfo typedefs */
-    typedef std::set<ServiceInfo> ServiceSet;
-    typedef ServiceSet::const_iterator ServiceConstIterator;
-    typedef ServiceSet::size_type ServiceSizeType;
+    using ServiceSet = std::set<ServiceInfo>;
+    using ServiceConstIterator = ServiceSet::const_iterator;
+    using ServiceSizeType = ServiceSet::size_type;
 
     /** RepoInfo typedefs */
-    typedef std::set<RepoInfo> RepoSet;
-    typedef RepoSet::const_iterator RepoConstIterator;
-    typedef RepoSet::size_type RepoSizeType;
+    using RepoSet = std::set<RepoInfo>;
+    using RepoConstIterator = RepoSet::const_iterator;
+    using RepoSizeType = RepoSet::size_type;
 
   public:
-   RepoManager( const RepoManagerOptions &options = RepoManagerOptions() );
+   RepoManager( RepoManagerOptions options = RepoManagerOptions() );
    /** Dtor */
     ~RepoManager();
 
-    enum RawMetadataRefreshPolicy
-    {
-      RefreshIfNeeded,
-      RefreshForced,
-      RefreshIfNeededIgnoreDelay
-    };
+    using RawMetadataRefreshPolicy = RepoManagerFlags::RawMetadataRefreshPolicy;
+    static constexpr RawMetadataRefreshPolicy RefreshIfNeeded             = RepoManagerFlags::RefreshIfNeeded;
+    static constexpr RawMetadataRefreshPolicy RefreshForced               = RepoManagerFlags::RefreshForced;
+    static constexpr RawMetadataRefreshPolicy RefreshIfNeededIgnoreDelay  = RepoManagerFlags::RefreshIfNeededIgnoreDelay;
 
-    enum CacheBuildPolicy
-    {
-      BuildIfNeeded,
-      BuildForced
-    };
+    using CacheBuildPolicy = RepoManagerFlags::CacheBuildPolicy;
+    static constexpr CacheBuildPolicy BuildIfNeeded = CacheBuildPolicy::BuildIfNeeded;
+    static constexpr CacheBuildPolicy BuildForced   = CacheBuildPolicy::BuildForced;
 
     /** Flags for tuning RefreshService */
-    enum RefreshServiceBit
-    {
-      RefreshService_restoreStatus	= (1<<0),	///< Force restoring repo enabled/disabled status
-      RefreshService_forceRefresh	= (1<<1),	///< Force refresh even if TTL is not reached
-    };
-    ZYPP_DECLARE_FLAGS(RefreshServiceFlags,RefreshServiceBit);
+    using RefreshServiceBit = RepoManagerFlags::RefreshServiceBit;
+    static constexpr RefreshServiceBit RefreshService_restoreStatus = RefreshServiceBit::RefreshService_restoreStatus;
+    static constexpr RefreshServiceBit RefreshService_forceRefresh  = RefreshServiceBit::RefreshService_forceRefresh;
+
+    using RefreshServiceFlags = RepoManagerFlags::RefreshServiceFlags;
 
     /** Options tuning RefreshService */
-    typedef RefreshServiceFlags RefreshServiceOptions;
-
+    using RefreshServiceOptions = RepoManagerFlags::RefreshServiceFlags;
 
     /** \name Known repositories.
      *
@@ -192,14 +137,10 @@ namespace zypp
     */
     RepoStatus metadataStatus( const RepoInfo &info ) const;
 
-    /**
-     * Possibly return state of checkIfRefreshMEtadata function
-     */
-    enum RefreshCheckStatus {
-      REFRESH_NEEDED,  /**< refresh is needed */
-      REPO_UP_TO_DATE, /**< repository not changed */
-      REPO_CHECK_DELAYED     /**< refresh is delayed due to settings */
-    };
+    using RefreshCheckStatus = RepoManagerFlags::RefreshCheckStatus;
+    static constexpr RefreshCheckStatus REFRESH_NEEDED     = RefreshCheckStatus::REFRESH_NEEDED;     /**< refresh is needed */
+    static constexpr RefreshCheckStatus REPO_UP_TO_DATE    = RefreshCheckStatus::REPO_UP_TO_DATE;    /**< repository not changed */
+    static constexpr RefreshCheckStatus REPO_CHECK_DELAYED = RefreshCheckStatus::REPO_CHECK_DELAYED; /**< refresh is delayed due to settings */
 
     /**
      * Checks whether to refresh metadata for specified repository and url.
@@ -649,7 +590,7 @@ namespace zypp
     struct MatchServiceAlias
     {
       public:
-        MatchServiceAlias( const std::string & alias_ ) : alias(alias_) {}
+        MatchServiceAlias( std::string  alias_ ) : alias(std::move(alias_)) {}
         bool operator()( const RepoInfo & info ) const
         { return info.service() == alias; }
       private:
@@ -705,11 +646,10 @@ namespace zypp
     /** Pointer to implementation */
     RWCOW_pointer<Impl> _pimpl;
   };
-  ZYPP_DECLARE_OPERATORS_FOR_FLAGS(RepoManager::RefreshServiceFlags);
   ///////////////////////////////////////////////////////////////////
 
   /** \relates RepoManager Stream output */
-  std::ostream & operator<<( std::ostream & str, const RepoManager & obj );
+  std::ostream & operator<<( std::ostream & str, const RepoManager & obj ) ZYPP_API;
 
   /** Iterate the known repositories. */
   inline Iterable<RepoManager::RepoConstIterator> RepoManager::repos() const
