@@ -26,14 +26,14 @@ namespace zypp
   //
   /** SrcPackage interface.
   */
-  class SrcPackage : public ResObject
+  class ZYPP_API SrcPackage : public ResObject
   {
 
   public:
-    typedef SrcPackage               Self;
-    typedef ResTraits<Self>          TraitsType;
-    typedef TraitsType::PtrType      Ptr;
-    typedef TraitsType::constPtrType constPtr;
+    using Self = SrcPackage;
+    using TraitsType = ResTraits<Self>;
+    using Ptr = TraitsType::PtrType;
+    using constPtr = TraitsType::constPtrType;
 
   public:
     /** The type of the source rpm ("src" or "nosrc"). */
@@ -54,7 +54,7 @@ namespace zypp
     /** Ctor */
     SrcPackage( const sat::Solvable & solvable_r );
     /** Dtor */
-    virtual ~SrcPackage();
+    ~SrcPackage() override;
   };
   ///////////////////////////////////////////////////////////////////
 
