@@ -107,7 +107,7 @@ namespace zypp
     {
         int level = 1;
 
-        unsigned int op_1_ecx = 0, op_80000001_ecx = 0, op_7_ebx = 0, unused;
+        unsigned int op_1_ecx = 0, op_80000001_ecx = 0, op_7_ebx = 0, unused = 0;
         cpuid(1, 0, &unused, &unused, &op_1_ecx, &unused);
         cpuid(0x80000001, 0, &unused, &unused, &op_80000001_ecx, &unused);
         cpuid(7, 0, &unused, &op_7_ebx, &unused, &unused);
@@ -258,7 +258,7 @@ namespace zypp
       else if ( architecture == Arch_ppc64 )
       {
         const char * platform = (const char *)getauxval( AT_PLATFORM );
-        int powerlvl;
+        int powerlvl = 0;
         if ( platform && sscanf( platform, "power%d", &powerlvl ) == 1 && powerlvl > 6 )
           architecture = Arch_ppc64p7;
       }
@@ -332,7 +332,7 @@ namespace zypp
   template<class Tp>
       struct Option
       {
-        typedef Tp value_type;
+        using value_type = Tp;
 
         /** No default ctor, explicit initialisation! */
         Option( value_type initial_r )
@@ -362,8 +362,8 @@ namespace zypp
   template<class Tp>
       struct DefaultOption : public Option<Tp>
       {
-        typedef Tp         value_type;
-        typedef Option<Tp> option_type;
+        using value_type = Tp;
+        using option_type = Option<Tp>;
 
         explicit DefaultOption( value_type initial_r )
         : Option<Tp>( initial_r )
@@ -404,7 +404,7 @@ namespace zypp
   */
   class ZConfig::Impl
   {
-    typedef std::set<std::string> MultiversionSpec;
+    using MultiversionSpec = std::set<std::string>;
 
     /// Settings that follow a changed Target
     struct TargetDefaults
@@ -516,7 +516,7 @@ namespace zypp
                 sit != dict.sectionsEnd();
                 ++sit )
           {
-            std::string section(*sit);
+            const std::string& section(*sit);
             //MIL << section << endl;
             for ( IniDict::entry_const_iterator it = dict.entriesBegin(*sit);
                   it != dict.entriesEnd(*sit);
@@ -720,8 +720,11 @@ namespace zypp
         MIL << "ZConfig singleton created." << endl;
       }
 
-      ~Impl()
-      {}
+      Impl(const Impl &) = delete;
+      Impl(Impl &&) = delete;
+      Impl &operator=(const Impl &) = delete;
+      Impl &operator=(Impl &&) = delete;
+      ~Impl() {}
 
       void notifyTargetChanged()
       {
@@ -830,7 +833,7 @@ namespace zypp
     // overlay all system specific values.
     struct MultiversionMap
     {
-      typedef std::map<Pathname,MultiversionSpec> SpecMap;
+      using SpecMap = std::map<Pathname, MultiversionSpec>;
 
       MultiversionSpec & getSpec( Pathname root_r, const Impl & zConfImpl_r )	// from system at root
       {
@@ -863,7 +866,7 @@ namespace zypp
       {	return _specMap[Pathname()]; }
 
     private:
-      int scanConfAt( const Pathname root_r, MultiversionSpec & spec_r, const Impl & zConfImpl_r )
+      int scanConfAt( const Pathname& root_r, MultiversionSpec & spec_r, const Impl & zConfImpl_r )
       {
         static const str::regex rx( "^multiversion *= *(.*)" );
         str::smatch what;
@@ -879,7 +882,7 @@ namespace zypp
                                 } );
       }
 
-      void scanDirAt( const Pathname root_r, MultiversionSpec & spec_r, const Impl & zConfImpl_r )
+      void scanDirAt( const Pathname& root_r, MultiversionSpec & spec_r, const Impl & zConfImpl_r )
       {
         // NOTE:  Actually we'd need to scan and use the root_r! zypp.conf values.
         Pathname multiversionDir( zConfImpl_r.cfg_multiversion_path );
