@@ -18,6 +18,7 @@
 #include <zypp/ExternalProgram.h>
 #include <zypp/base/String.h>
 #include <zypp/base/Gettext.h>
+#include <utility>
 #include <zypp-core/parser/Sysconfig>
 #include <zypp/base/Gettext.h>
 
@@ -58,8 +59,17 @@ namespace internal {
     , _isOptional { isOptional }
     { connect(); }
 
-    ~OptionalDownloadProgressReport()
-    { if ( _oldRec ) Distributor::instance().setReceiver( *_oldRec ); else Distributor::instance().noReceiver(); }
+    OptionalDownloadProgressReport(const OptionalDownloadProgressReport &) = delete;
+    OptionalDownloadProgressReport(OptionalDownloadProgressReport &&) = delete;
+    OptionalDownloadProgressReport &operator= (const OptionalDownloadProgressReport &) = delete;
+    OptionalDownloadProgressReport &operator= (OptionalDownloadProgressReport &&) = delete;
+
+    ~OptionalDownloadProgressReport() override {
+      if (_oldRec)
+        Distributor::instance().setReceiver(*_oldRec);
+      else
+        Distributor::instance().noReceiver();
+    }
 
     void reportbegin() override
     { if ( _oldRec ) _oldRec->reportbegin(); }
@@ -123,7 +133,7 @@ namespace internal {
     {
       if ( _isOptional ) {
         // we know _oldRec is valid...
-        _oldRec->start( std::move(_startFile), std::move(_startLocalfile) );
+        _oldRec->start( _startFile, std::move(_startLocalfile) );
         _isOptional = false;
       }
     }
@@ -138,7 +148,7 @@ namespace internal {
 
   struct ProgressData
   {
-    ProgressData( CURL *curl, time_t timeout = 0, const zypp::Url & url = zypp::Url(),
+    ProgressData( CURL *curl, time_t timeout = 0, zypp::Url  url = zypp::Url(),
                   zypp::ByteCount expectedFileSize_r = 0,
                   zypp::callback::SendReport<zypp::media::DownloadProgressReport> *_report = nullptr );
 
@@ -187,9 +197,9 @@ namespace internal {
 
 
 
-  ProgressData::ProgressData(CURL *curl, time_t timeout, const Url &url, ByteCount expectedFileSize_r, zypp::callback::SendReport< zypp::media::DownloadProgressReport> *_report)
+  ProgressData::ProgressData(CURL *curl, time_t timeout, Url url, ByteCount expectedFileSize_r, zypp::callback::SendReport< zypp::media::DownloadProgressReport> *_report)
     : _curl( curl )
-    , _url( url )
+    , _url(std::move( url ))
     , _timeout( timeout )
     , _timeoutReached( false )
     , _fileSizeExceeded ( false )
@@ -379,6 +389,13 @@ void MediaCurl::setCookieFile( const Pathname &fileName )
   _cookieFile = fileName;
 }
 
+void MediaCurl::setCurlError(const char* error)
+{
+  // FIXME(dmllr): Use strlcpy if available for better performance
+  strncpy(_curlError, error, sizeof(_curlError)-1);
+  _curlError[sizeof(_curlError)-1] = '\0';
+}
+
 ///////////////////////////////////////////////////////////////////
 
 void MediaCurl::checkProtocol(const Url &url) const
@@ -388,7 +405,7 @@ void MediaCurl::checkProtocol(const Url &url) const
   // curl_info does not need any free (is static)
   if (curl_info->protocols)
   {
-    const char * const *proto;
+    const char * const *proto = nullptr;
     std::string        scheme( url.getScheme());
     bool               found = false;
     for(proto=curl_info->protocols; !found && *proto; ++proto)
@@ -478,10 +495,7 @@ void MediaCurl::setupEasy()
 
   if ( _url.getScheme() == "https" )
   {
-    // restrict following of redirections from https to https only
-    // but be less restrictive for d.o.o
-    bool allowHttp = ( _url.getHost() == "download.opensuse.org" );
-    if ( :: internal::setCurlRedirProtocols ( _curl, allowHttp ) != CURLE_OK ) {
+    if ( :: internal::setCurlRedirProtocols ( _curl ) != CURLE_OK ) {
       ZYPP_THROW(MediaCurlSetOptException(_url, _curlError));
     }
 
@@ -628,7 +642,9 @@ void MediaCurl::setupEasy()
   _currentCookieFile = _cookieFile.asString();
   if ( ::geteuid() == 0 || PathInfo(_currentCookieFile).owner() == ::geteuid() )
     filesystem::assert_file_mode( _currentCookieFile, 0600 );
-  if ( str::strToBool( _url.getQueryParam( "cookies" ), true ) )
+
+  const auto &cookieFileParam = _url.getQueryParam( "cookies" );
+  if ( !cookieFileParam.empty() && str::strToBool( cookieFileParam, true ) )
     SET_OPTION(CURLOPT_COOKIEFILE, _currentCookieFile.c_str() );
   else
     MIL << "No cookies requested" << endl;
@@ -947,13 +963,6 @@ void MediaCurl::evaluateCurlCode(const Pathname &filename,
         }
         break;
 
-      // Attempt to work around certain issues by autoretry in MediaCurl::getFileCopy
-      case CURLE_HTTP2:
-      case CURLE_HTTP2_STREAM:
-        err = "Curl error " + str::numstring( code );
-        ZYPP_THROW(MediaCurlExceptionMayRetryInternaly(url, err, _curlError));
-        break;
-
       default:
         err = "Curl error " + str::numstring( code );
         break;
@@ -1015,16 +1024,18 @@ bool MediaCurl::doGetDoesFileExist( const Pathname & filename ) const
   /// RAII Handler for temp. setting a head/range request
   struct TempSetHeadRequest
   {
-    TempSetHeadRequest( CURL * curl_r, bool doHttpHeadRequest_r )
-    : _curl { curl_r }
-    , _doHttpHeadRequest { doHttpHeadRequest_r }
-    {
+    TempSetHeadRequest(CURL *curl_r, bool doHttpHeadRequest_r)
+      : _curl{curl_r}, _doHttpHeadRequest{doHttpHeadRequest_r} {
       if ( _doHttpHeadRequest ) {
         curl_easy_setopt( _curl, CURLOPT_NOBODY, 1L );
       } else {
         curl_easy_setopt( _curl, CURLOPT_RANGE, "0-1" );
       }
     }
+    TempSetHeadRequest(const TempSetHeadRequest &) = delete;
+    TempSetHeadRequest(TempSetHeadRequest &&) = delete;
+    TempSetHeadRequest &operator=(const TempSetHeadRequest &) = delete;
+    TempSetHeadRequest &operator=(TempSetHeadRequest &&) = delete;
     ~TempSetHeadRequest() {
       if ( _doHttpHeadRequest ) {
         curl_easy_setopt( _curl, CURLOPT_NOBODY, 0L);
@@ -1454,8 +1465,8 @@ CURLcode MediaCurl::executeCurl() const
         ZYPP_THROW(MediaCurlException(_url, "curl_multi_socket_action", "unknown error"));
     }
 
-    CURLMsg *msg;
-    int nqueue;
+    CURLMsg *msg = nullptr;
+    int nqueue = 0;
     while ((msg = curl_multi_info_read( cMulti->_multi, &nqueue)) != 0) {
         if ( msg->msg != CURLMSG_DONE  ) continue;
         if ( msg->easy_handle != _curl ) continue;
