@@ -26,6 +26,7 @@ extern "C"
 #include <map>
 #include <set>
 #include <string>
+#include <utility>
 #include <vector>
 #include <algorithm>
 
@@ -139,23 +140,24 @@ inline std::string rpmQuoteFilename( const Pathname & path_r )
 
 struct KeyRingSignalReceiver : callback::ReceiveReport<KeyRingSignals>
 {
-  KeyRingSignalReceiver(RpmDb &rpmdb) : _rpmdb(rpmdb)
-  {
-    connect();
-  }
+  KeyRingSignalReceiver(RpmDb &rpmdb) : _rpmdb(rpmdb) { connect(); }
+  KeyRingSignalReceiver(const KeyRingSignalReceiver &) = delete;
+  KeyRingSignalReceiver(KeyRingSignalReceiver &&) = delete;
+  KeyRingSignalReceiver &operator=(const KeyRingSignalReceiver &) = delete;
+  KeyRingSignalReceiver &operator=(KeyRingSignalReceiver &&) = delete;
 
-  ~KeyRingSignalReceiver()
+  ~KeyRingSignalReceiver() override
   {
     disconnect();
   }
 
-  virtual void trustedKeyAdded( const PublicKey &key )
+  void trustedKeyAdded( const PublicKey &key ) override
   {
     MIL << "trusted key added to zypp Keyring. Importing..." << endl;
     _rpmdb.importPubkey( key );
   }
 
-  virtual void trustedKeyRemoved( const PublicKey &key  )
+  void trustedKeyRemoved( const PublicKey &key  ) override
   {
     MIL << "Trusted key removed from zypp Keyring. Removing..." << endl;
     _rpmdb.removePubkey( key );
@@ -166,7 +168,7 @@ struct KeyRingSignalReceiver : callback::ReceiveReport<KeyRingSignals>
 
 static shared_ptr<KeyRingSignalReceiver> sKeyRingReceiver;
 
-unsigned diffFiles(const std::string file1, const std::string file2, std::string& out, int maxlines)
+unsigned diffFiles(const std::string& file1, const std::string& file2, std::string& out, int maxlines)
 {
   const char* argv[] =
     {
@@ -797,7 +799,7 @@ void RpmDb::importPubkey( const PublicKey & pubkey_r )
     RpmSubprocessException excp( str::Format(_("Failed to import public key %1%") ) % pubkey_r.asString() );
     excp.moveToHistory( excplines );
     excp.addHistory( std::move(error_message) );
-    ZYPP_THROW( std::move(excp) );
+    ZYPP_THROW( excp );
   }
   else
   {
@@ -864,7 +866,7 @@ void RpmDb::removePubkey( const PublicKey & pubkey_r )
     RpmSubprocessException excp( str::Format(_("Failed to remove public key %1%") ) % pubkey_r.asString() );
     excp.moveToHistory( excplines );
     excp.addHistory( std::move(error_message) );
-    ZYPP_THROW( std::move(excp) );
+    ZYPP_THROW( excp );
   }
   else
   {
@@ -945,7 +947,7 @@ RpmDb::fileList( const std::string & name_r, const Edition & edition_r ) const
   std::list<FileInfo> result;
 
   librpmDb::db_const_iterator it;
-  bool found;
+  bool found = false;
   if (edition_r == Edition::noedition)
   {
     found = it.findPackage( name_r );
@@ -972,7 +974,7 @@ RpmDb::fileList( const std::string & name_r, const Edition & edition_r ) const
 bool RpmDb::hasFile( const std::string & file_r, const std::string & name_r ) const
 {
   librpmDb::db_const_iterator it;
-  bool res;
+  bool res = false;
   do
   {
     res = it.findByFile( file_r );
@@ -1122,8 +1124,12 @@ namespace
       _oldMask = rpmlogSetMask( RPMLOG_UPTO( RPMLOG_PRI(RPMLOG_INFO) ) );
     }
 
-    ~RpmlogCapture()
-    {
+    RpmlogCapture(const RpmlogCapture &) = delete;
+    RpmlogCapture(RpmlogCapture &&) = delete;
+    RpmlogCapture &operator=(const RpmlogCapture &) = delete;
+    RpmlogCapture &operator=(RpmlogCapture &&) = delete;
+
+    ~RpmlogCapture() {
       rpmlogSetCallback( nullptr, nullptr );
       rpmlogSetMask( _oldMask );
     }
@@ -1247,7 +1253,7 @@ namespace
       }
 
       ++count[lineres];
-      detail_r.push_back( RpmDb::CheckPackageDetail::value_type( lineres, std::move(line) ) );
+      detail_r.push_back( RpmDb::CheckPackageDetail::value_type( lineres, line ) );
     }
 
     // Now combine the overall result:
@@ -1777,7 +1783,7 @@ void RpmDb::doInstallPackage( const Pathname & filename, RpmInstFlags flags, Rpm
   {
     if ( str::startsWith( line, "%%" ) )
     {
-      int percent;
+      int percent = 0;
       sscanf( line.c_str() + 2, "%d", &percent );
       report->progress( percent );
       continue;
@@ -1837,7 +1843,7 @@ void RpmDb::doInstallPackage( const Pathname & filename, RpmInstFlags flags, Rpm
     auto excpt { RpmSubprocessException(_("RPM failed: ") + error_message ) };
     if ( not rpmmsg.empty() )
       excpt.addHistory( rpmmsg );
-    ZYPP_THROW(std::move(excpt));
+    ZYPP_THROW(excpt);
   }
   else if ( ! rpmmsg.empty() )
   {
@@ -1859,12 +1865,12 @@ void RpmDb::doInstallPackage( const Pathname & filename, RpmInstFlags flags, Rpm
 //	METHOD NAME : RpmDb::removePackage
 //
 void RpmDb::removePackage( Package::constPtr package, RpmInstFlags flags )
-{ removePackage( package, flags, nullptr ); }
+{ removePackage( std::move(package), flags, nullptr ); }
 
 void RpmDb::removePackage( const std::string & name_r, RpmInstFlags flags )
 { removePackage( name_r, flags, nullptr ); }
 
-void RpmDb::removePackage( Package::constPtr package, RpmInstFlags flags, RpmPostTransCollector* postTransCollector_r )
+void RpmDb::removePackage( const Package::constPtr& package, RpmInstFlags flags, RpmPostTransCollector* postTransCollector_r )
 { // 'rpm -e' does not like epochs
   removePackage( package->name()
                  + "-" + package->edition().version()
@@ -2010,7 +2016,7 @@ void RpmDb::doRemovePackage( const std::string & name_r, RpmInstFlags flags, Rpm
     auto excpt { RpmSubprocessException(_("RPM failed: ") + error_message ) };
     if ( not rpmmsg.empty() )
       excpt.addHistory( rpmmsg );
-    ZYPP_THROW(std::move(excpt));
+    ZYPP_THROW(excpt);
   }
   else if ( ! rpmmsg.empty() )
   {
@@ -2031,7 +2037,7 @@ void RpmDb::doRemovePackage( const std::string & name_r, RpmInstFlags flags, Rpm
 //
 //	METHOD NAME : RpmDb::runposttrans
 //
-int RpmDb::runposttrans( const Pathname & filename_r, std::function<void(const std::string&)> output_r )
+int RpmDb::runposttrans( const Pathname & filename_r, const std::function<void(const std::string&)>& output_r )
 {
   FAILIFNOTINITIALIZED;
   HistoryLog historylog;
