@@ -46,14 +46,14 @@ namespace rpm
 /**
  * @short Interface to the rpm program
  **/
-class RpmDb : public base::ReferenceCounted, private base::NonCopyable
+class ZYPP_API RpmDb : public base::ReferenceCounted, private base::NonCopyable
 {
 public:
 
   /**
    * Default error class
    **/
-  typedef class InstTargetError Error;
+  using Error = class InstTargetError;
 
   ///////////////////////////////////////////////////////////////////
   //
@@ -83,7 +83,7 @@ public:
   /**
    * Destructor.
    **/
-  ~RpmDb();
+  ~RpmDb() override;
 
   /**
    * @return Root directory for all operations (empty if not initialized).
@@ -277,7 +277,7 @@ private:
   */
   ExternalProgram *process;
 
-  typedef std::vector<const char*> RpmArgVec;
+  using RpmArgVec = std::vector<const char *>;
 
   /**
    * Run rpm with the specified arguments and handle stderr.
@@ -344,7 +344,7 @@ private:
 
 public:
 
-  typedef std::set<std::string> FileList;
+  using FileList = std::set<std::string>;
 
   /**
    * checkPackage result
@@ -422,13 +422,13 @@ public:
   void removePackage( Package::constPtr package, RpmInstFlags flags = RPMINST_NONE );
   /** \overload For delayed %posttrans %transfiletrigger(postun|in) execution if driven by Target::commit. */
   void removePackage( const std::string & name_r, RpmInstFlags flags, RpmPostTransCollector* postTransCollector_r );
-  void removePackage( Package::constPtr package, RpmInstFlags flags, RpmPostTransCollector* postTransCollector_r );
+  void removePackage( const Package::constPtr& package, RpmInstFlags flags, RpmPostTransCollector* postTransCollector_r );
 
   /** Run collected %posttrans and %transfiletrigger(postun|in) if `rpm --runposttrans` is supported.
    * Output-function receives a "RIPOFF:%scriptident(packageident)" line for every script
    * that is executed followed by lines the script outputs to stout/stderr.
    */
-  int runposttrans( const Pathname & filename_r, std::function<void(const std::string&)> output_r );
+  int runposttrans( const Pathname & filename_r, const std::function<void(const std::string&)>& output_r );
 
   /**
    * get backup dir for rpm config files
@@ -491,7 +491,7 @@ public:
   /**
    * Dump debug info.
    **/
-  virtual std::ostream & dumpOn( std::ostream & str ) const;
+  std::ostream & dumpOn( std::ostream & str ) const override;
 
 protected:
   void doRemovePackage( const std::string & name_r, RpmInstFlags flags, RpmPostTransCollector* postTransCollector_r, callback::SendReport<RpmRemoveReport> & report );
@@ -500,10 +500,10 @@ protected:
 };
 
 /** \relates RpmDb::CheckPackageResult Stream output */
-std::ostream & operator<<( std::ostream & str, RpmDb::CheckPackageResult obj );
+std::ostream & operator<<( std::ostream & str, RpmDb::CheckPackageResult obj ) ZYPP_API;
 
 /** \relates RpmDb::checkPackageDetail Stream output */
-std::ostream & operator<<( std::ostream & str, const RpmDb::CheckPackageDetail & obj );
+std::ostream & operator<<( std::ostream & str, const RpmDb::CheckPackageDetail & obj ) ZYPP_API;
 
 } // namespace rpm
 } // namespace target
