@@ -12,6 +12,7 @@
 #include "librpm.h"
 
 #include <iostream>
+#include <utility>
 
 #include <zypp/base/Logger.h>
 #include <zypp/PathInfo.h>
@@ -38,8 +39,10 @@ namespace rpm
  **/
 class librpmDb::D
 {
-  D & operator=( const D & ); // NO ASSIGNMENT!
-  D ( const D & );            // NO COPY!
+  D ( const D & ) = delete;            // NO COPY!
+  D & operator=( const D & ) = delete; // NO ASSIGNMENT!
+  D(D &&) = delete;
+  D &operator=(D &&) = delete;
 public:
 
   const Pathname _root;   // root directory for all operations
@@ -53,11 +56,8 @@ public:
     return str;
   }
 
-  D( const Pathname & root_r, const Pathname & dbPath_r, bool readonly_r )
-      : _root  ( root_r )
-      , _dbPath( dbPath_r )
-      , _ts    ( 0 )
-  {
+  D(Pathname root_r, Pathname dbPath_r, bool readonly_r)
+    : _root(std::move(root_r)), _dbPath(std::move(dbPath_r)), _ts(0) {
     _error.reset();
     // set %_dbpath macro
     ::addMacro( NULL, "_dbpath", NULL, _dbPath.asString().c_str(), RMIL_CMDLINE );
@@ -485,8 +485,10 @@ std::ostream & librpmDb::dumpOn( std::ostream & str ) const
  **/
 class librpmDb::db_const_iterator::D
 {
-  D & operator=( const D & ); // NO ASSIGNMENT!
-  D ( const D & );            // NO COPY!
+  D & operator=( const D & ) = delete; // NO ASSIGNMENT!
+  D ( const D & ) = delete;            // NO COPY!
+  D(D &&);
+  D &operator=(D &&) = delete;
 public:
 
   librpmDb::constPtr     _dbptr;
@@ -495,10 +497,7 @@ public:
   RpmHeader::constPtr _hptr;
   rpmdbMatchIterator   _mi;
 
-  D( librpmDb::constPtr dbptr_r )
-      : _dbptr( dbptr_r )
-      , _mi( 0 )
-  {
+  D(librpmDb::constPtr dbptr_r) : _dbptr(std::move(dbptr_r)), _mi(0) {
     if ( !_dbptr )
     {
       try
@@ -634,7 +633,7 @@ public:
 //	METHOD TYPE : Constructor
 //
 librpmDb::db_const_iterator::db_const_iterator( librpmDb::constPtr dbptr_r )
-    : _d( * new D( dbptr_r ) )
+    : _d( * new D( std::move(dbptr_r) ) )
 {
   findAll();
 }
